#!/usr/bin/env python
# -*- coding: utf-8 -*-


import json
import os
from HTTPerror import HTTP404Error, HTTP302Error
from server import static_setting


class HeaderError(Exception):

    def __init__(self):
        pass


class HeaderTupleError(HeaderError):

    def __init__(self):
        print "<the header must be two tuples>"
        HeaderError.__init__()


def render(filename, extra_header=None):
    if static_setting['templates'][-1] != '/':
        static_setting['templates'] = static_setting['templates'] + '/'

    try:
        with open(os.path.abspath(static_setting['templates'] + filename), "r") as f:
            res = f.read()

        if not extra_header:
            return (res, [('Content-Type', 'text/html')])
        else:
            if isinstance(extra_header, tuple):
                if len(extra_header) == 2:
                    extra_header = [
                        ('Content-Type', 'text/html'), extra_header]
                    return (res, extra_header)
                else:
                    raise HeaderTupleError
            elif isinstance(extra_header, list):
                for header in extra_header:
                    if len(header) != 2:
                        raise HeaderTupleError
                extra_header.append(('Content-Type', 'text/html'))
                return (res, extra_header)
            else:
                raise HeaderTupleError

    except IOError:
        print "<NO SUCH FILE>"
        raise HTTP404Error


def render_json(data, extra_header=None, indent=0):
    if not extra_header:
        return (json.dumps(data, ensure_ascii=False, indent=indent), [('Content-Type', 'application/json')])
    else:
        if isinstance(extra_header, tuple):
            if len(extra_header) == 2:
                extra_header = [
                    ('Content-Type', 'text/html'), extra_header]
                return (json.dumps(data, ensure_ascii=False, indent=indent), extra_header)
            else:
                raise HeaderTupleError
        elif isinstance(extra_header, list):
            for header in extra_header:
                if len(header) != 2:
                    raise HeaderTupleError
            extra_header.append(('Content-Type', 'text/html'))
            return (json.dumps(data, ensure_ascii=False, indent=indent), extra_header)
        else:
            raise HeaderTupleError


def render_media(filename):
    if static_setting['statics'][-1] != '/':
        static_setting['statics'] = static_setting['statics'] + '/'

    try:
        with open(os.path.abspath(static_setting['statics'] + filename), "r") as f:
            res = f.read()

        if 'css' in filename[-4:]:
            content = ('Content-Type', 'text/css')
        elif 'js' in filename[-4:]:
            content = ('Content-Type', 'application/javascript')
        else:
            raise HTTP404Error
        return (res, content)

    except IOError:
        raise HTTP404Error


def redirect(path):

    raise HTTP302Error(path)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


class HTTPError(Exception):
    error_code = None
    value = ''

    def __init__(self, info=None):
        self.info = info
        if self.info:
            print '<' + self.info + '>'


class HTTP404Error(HTTPError):
    error_code = 404

    def __init__(self, info=None):
        if info:
            HTTPError.__init__(self, info)
        else:
            HTTPError.__init__(self)
        self.error_header = '404 NOT FOUND'

    def __str__(self):
        return "<404 NOT FOUND>"


class HTTP502Error(HTTPError):
    error_code = 502

    def __str__(self):
        return "<502 SERVER ERROR>"


class HTTP403Error(HTTPError):
    error_code = 403

    def __init__(self, info=None):
        if info:
            HTTPError.__init__(self, info)
        else:
            HTTPError.__init__(self)
        self.error_header = '403 Forbidden'

    def __str__(self):
        return "<403 FORBBIDEN>"


class HTTP500Error(HTTPError):
    error_code = 500

    def __str__(self):
        return "<server error>"


class HTTP400Error(HTTPError):
    error_code = 400

    def __init__(self, info=None):
        if info:
            HTTPError.__init__(self, info)
        else:
            HTTPError.__init__(self)
        self.error_header = '400 Bad Request'

    def __str__(self):
        return "<400 Bad Request>"


class HTTP302Error(HTTPError):
    error_code = 301

    def __init__(self, target_url, info=None):
        if info:
            HTTPError.__init__(self, info)
        else:
            HTTPError.__init__(self)
        self.error_header = '302 Found'
        self.target_url = target_url

    def __str__(self):
        return "<302 Found>"




import re
from setuptools import setup
import ast

setup(
    name='jolla',
    keywords=['back-end', 'framework', 'RESTful', 'gevent'],
    version='1.1.8',
    description='high performance RESTful framework',
    author='aljun',
    author_email='salamer_gaga@163.com',
    license='Apache',
    url='https://github.com/salamer/jolla',
    download_url='https://github.com/salamer/jolla',

    install_requires=[
        'gevent'
    ],

    packages=['jolla'],

    classifiers=[
        'Development Status :: 3 - Alpha',
        "License :: OSI Approved :: Apache Software License",
        'Environment :: Web Environment',
        "Programming Language :: Python :: 2.7",
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from server import WebApp, jolla_server, RouteError, RequestError, RequestValueError
from plugins import *
from HTTPerror import *
from session import *
